@@ -194,7 +194,7 @@
     <message>
         <location filename="mainwindow.cpp" line="284"/>
         <source>Program for formatting USB devices</source>
-        <translation>USB devices 用のフォーマット・アプリ</translation>
+        <translation>USB デバイスのフォーマット用アプリ</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="286"/>
